aboutsummaryrefslogtreecommitdiffstats
path: root/controller-api/src
diff options
context:
space:
mode:
Diffstat (limited to 'controller-api/src')
-rw-r--r--controller-api/src/main/java/com/yahoo/vespa/hosted/controller/api/integration/deployment/ArtifactRepository.java8
1 files changed, 4 insertions, 4 deletions
diff --git a/controller-api/src/main/java/com/yahoo/vespa/hosted/controller/api/integration/deployment/ArtifactRepository.java b/controller-api/src/main/java/com/yahoo/vespa/hosted/controller/api/integration/deployment/ArtifactRepository.java
index b44e7f6f5e7..117dbd38a3b 100644
--- a/controller-api/src/main/java/com/yahoo/vespa/hosted/controller/api/integration/deployment/ArtifactRepository.java
+++ b/controller-api/src/main/java/com/yahoo/vespa/hosted/controller/api/integration/deployment/ArtifactRepository.java
@@ -21,10 +21,10 @@ public interface ArtifactRepository {
/** Returns the system application package of the given version. */
byte[] getSystemApplicationPackage(ApplicationId application, ZoneId zone, Version version);
- /** Stores the given tester application fat jar of the given version. */
- void putTesterJar(ApplicationId tester, String applicationVersion, byte[] fatTestJar);
+ /** Stores the given tester application package of the given version. Does NOT contain the services.xml. */
+ void putTesterPackage(ApplicationId tester, String applicationVersion, byte[] testerPackage);
- /** Returns the tester application fat jar of the given version. */
- byte[] getTesterJar(ApplicationId tester, String applicationVersion);
+ /** Returns the tester application package of the given version. Does NOT contain the services.xml. */
+ byte[] getTesterPackage(ApplicationId tester, String applicationVersion);
}